@@ -3,8 +3,12 @@ use twilight_model::{
         command::{Command, CommandOption, CommandType, Number, OptionsCommandOptionData},
         interaction::application_command::InteractionChannel,
     },
+    channel::Attachment,
     guild::Role,
-    id::{ChannelId, CommandVersionId, GenericId, RoleId, UserId},
+    id::{
+        marker::{AttachmentMarker, ChannelMarker, GenericMarker, RoleMarker, UserMarker},
+        Id,
+    },
     user::User,
 };
 
@@ -72,6 +76,9 @@ use super::{internal::CreateOptionData, ResolvedUser};
 /// [`CommandModel`]: super::CommandModel
 /// [`ChannelType`]: twilight_model::channel::ChannelType
 pub trait CreateCommand: Sized {
+    /// Name of the command.
+    const NAME: &'static str;
+
     /// Create an [`ApplicationCommandData`] for this type.
     fn create_command() -> ApplicationCommandData;
 }
@@ -145,7 +152,7 @@ impl From<ApplicationCommandData> for Command {
             id: None,
             kind: CommandType::ChatInput,
             options: item.options,
-            version: CommandVersionId::new(1).unwrap(),
+            version: Id::new(1),
         }
     }
 }
@@ -196,30 +203,42 @@ impl CreateOption for bool {
     }
 }
 
-impl CreateOption for UserId {
+impl CreateOption for Id<UserMarker> {
     fn create_option(data: CreateOptionData) -> CommandOption {
         CommandOption::User(data.into_data())
     }
 }
 
-impl CreateOption for ChannelId {
+impl CreateOption for Id<ChannelMarker> {
     fn create_option(data: CreateOptionData) -> CommandOption {
         CommandOption::Channel(data.into_channel())
     }
 }
 
-impl CreateOption for RoleId {
+impl CreateOption for Id<RoleMarker> {
     fn create_option(data: CreateOptionData) -> CommandOption {
         CommandOption::Role(data.into_data())
     }
 }
 
-impl CreateOption for GenericId {
+impl CreateOption for Id<GenericMarker> {
     fn create_option(data: CreateOptionData) -> CommandOption {
         CommandOption::Mentionable(data.into_data())
     }
 }
 
+impl CreateOption for Id<AttachmentMarker> {
+    fn create_option(data: CreateOptionData) -> CommandOption {
+        CommandOption::Attachment(data.into_data())
+    }
+}
+
+impl CreateOption for Attachment {
+    fn create_option(data: CreateOptionData) -> CommandOption {
+        CommandOption::Attachment(data.into_data())
+    }
+}
+
 impl CreateOption for User {
     fn create_option(data: CreateOptionData) -> CommandOption {
         CommandOption::User(data.into_data())
